@@ -1,5 +1,5 @@
 
-# $Id: Stores.pm,v 1.9 2005/08/30 03:13:35 Daddy Exp $
+# $Id: Stores.pm,v 1.11 2007/05/20 13:32:56 Daddy Exp $
 
 =head1 NAME
 
@@ -41,8 +41,8 @@ Please tell the author if you find any!
 
 =head1 AUTHOR
 
-C<WWW::Search::Ebay::Stores> was written by Martin Thurn
-(mthurn@cpan.org).
+C<WWW::Search::Ebay::Stores> was written by and is maintained by
+Martin Thurn C<mthurn@cpan.org>, L<http://tinyurl.com/nn67z>.
 
 Some fixes along the way contributed by Troy Davis.
 
@@ -50,10 +50,11 @@ Some fixes along the way contributed by Troy Davis.
 
 package WWW::Search::Ebay::Stores;
 
-use WWW::Search::Ebay;
-use vars qw( @ISA $VERSION );
-@ISA = qw( WWW::Search::Ebay );
-$VERSION = do { my @r = (q$Revision: 1.9 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+use strict;
+
+use base 'WWW::Search::Ebay';
+our
+$VERSION = do { my @r = (q$Revision: 1.11 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub native_setup_search
   {
